Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type FrameIndex ¶
type GVHeader ¶
type GVHeader struct {
Width uint32
Height uint32
FrameCount uint32
FPS float32
Format uint32 // 0 = Raw RGBA
FrameBytes uint32 // Total uncompressed bytes per frame
}
GVHeader matches the binary format produced by images2gv
type VideoResource ¶
type VideoResource struct {
Header GVHeader
File *os.File
Indices []FrameIndex
Texture *sdl.Texture
RGBA []byte
FPS float64
W, H float32
LastFrame int // Index of last decoded frame
}
func (*VideoResource) Destroy ¶
func (v *VideoResource) Destroy()
func (*VideoResource) UpdateFrame ¶
func (v *VideoResource) UpdateFrame(targetFrame int) bool
Directories
¶
| Path | Synopsis |
|---|---|
|
Package clock provides timing helpers: Wait, GetTime, and a Clock for measuring durations and sleeping until a target offset.
|
Package clock provides timing helpers: Wait, GetTime, and a Clock for measuring durations and sleeping until a target offset. |
|
Package control manages the overall state and initialization of an experiment.
|
Package control manages the overall state and initialization of an experiment. |
|
Package design provides experiment structure types (trials, blocks, factors) and randomization helpers for building experiment designs.
|
Package design provides experiment structure types (trials, blocks, factors) and randomization helpers for building experiment designs. |
|
Package geometry provides point/distance and coordinate conversion helpers (Euclidean distance, Cartesian–polar conversion, degree–radian).
|
Package geometry provides point/distance and coordinate conversion helpers (Euclidean distance, Cartesian–polar conversion, degree–radian). |
|
Package io provides the low-level input/output subsystems for goxpyriment:
|
Package io provides the low-level input/output subsystems for goxpyriment: |
|
Package stimuli provides visual and auditory stimulus types (fixation cross, text, pictures, video, shapes, sound, etc.) that implement the Stimulus and VisualStimulus interfaces for use with the experiment Screen.
|
Package stimuli provides visual and auditory stimulus types (fixation cross, text, pictures, video, shapes, sound, etc.) that implement the Stimulus and VisualStimulus interfaces for use with the experiment Screen. |
|
tests
|
|
|
player
command
|
Click to show internal directories.
Click to hide internal directories.